//------------------------------------------------------------------------------
// Title        : MEM_SP_xKx16.v 
// Project      : FT600 Bus Master
//------------------------------------------------------------------------------
// Author       : W.K 
//------------------------------------------------------------------------------
// Description  : 
//                FPGA SRAM wrapper 
//
//             
//------------------------------------------------------------------------------
// Known issues & omissions:
// 
// 
//------------------------------------------------------------------------------

`ifndef FTDI_SIM
  `include "define_conf.v"

  `ifdef VX6
    `ifdef MEM_64K
      `include "../RTL/memory/V6_SP_32Kx16.v"
    `else
      `include "../RTL/memory/V6_SP_8Kx16.v"
    `endif
  `else
    `include "../RTL/memory/SP6_SP_8Kx16.v"
  `endif
`endif

module  MEM_SP_xKx16 #(
  parameter T_MSZ = 13
) (
  input  wire        rstn,
  output wire [15:0] Q,
  input  wire [15:0] D,
  input  wire [T_MSZ-1:0] A,
  input  wire        CE,
  input  wire [1:0]  WE,
  input  wire        CLK
  );


`ifdef FTDI_SIM

  mem_xKx16_mdl #(
  .T_MSZ(T_MSZ)
  ) i_mem_xKx16_mdl (
    .rstn(rstn),
    .clk(CLK),
    .ce(CE),
    .wen(WE),
    .din(D), 
    .addr(A), 
    .qout(Q) 
  );  

`else

  `ifdef VX6 

    `ifdef MEM_64K
      V6_SP_32Kx16 i_V6_SP_32Kx16 (
    `else
      V6_SP_8Kx16 i_V6_SP_8Kx16 (
    `endif
       .dina(D),
       .addra(A),
       .ena(CE),
       .wea(WE),
       .clka(CLK),
       .douta(Q)
      );

  `else

    SP6_SP_8Kx16 i_SP6_SP_8Kx16 (
      .dina(D),
      .addra(A),
      .ena(CE),
      .wea(WE),
      .clka(CLK),
      .douta(Q)
    );

  `endif

`endif


endmodule

